@@ -36,9 +36,9 @@ class Postgres_Handler:
                     if results.count == 0:
                         results = 'No records found'
                 except psycopg2.ProgrammingError as ex:
-                    if ex == "no results to fetch":
-                        status = 2
-                        results = "Success"
+                    #if ex == "no results to fetch":
+                    status = 2
+                    results = "Success"
                 except Exception as ex:
                     status = -1
                     results = f"{ex}"
